package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcMaterial;

/**
 * cmc耗材信息Mapper接口
 * 
 * @author cmc
 * @date 2024-07-31
 */
public interface CmcMaterialMapper 
{
    /**
     * 查询cmc耗材信息
     * 
     * @param materialId cmc耗材信息主键
     * @return cmc耗材信息
     */
    public CmcMaterial selectCmcMaterialByMaterialId(Integer materialId);

    /**
     * 查询cmc耗材信息列表
     * 
     * @param cmcMaterial cmc耗材信息
     * @return cmc耗材信息集合
     */
    public List<CmcMaterial> selectCmcMaterialList(CmcMaterial cmcMaterial);

    /**
     * 新增cmc耗材信息
     * 
     * @param cmcMaterial cmc耗材信息
     * @return 结果
     */
    public int insertCmcMaterial(CmcMaterial cmcMaterial);

    /**
     * 修改cmc耗材信息
     * 
     * @param cmcMaterial cmc耗材信息
     * @return 结果
     */
    public int updateCmcMaterial(CmcMaterial cmcMaterial);

    /**
     * 删除cmc耗材信息
     * 
     * @param materialId cmc耗材信息主键
     * @return 结果
     */
    public int deleteCmcMaterialByMaterialId(Integer materialId);

    /**
     * 批量删除cmc耗材信息
     * 
     * @param materialIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcMaterialByMaterialIds(Integer[] materialIds);
}
